@@ -179,6 +179,8 @@ class TrackMeGetCollection(GeneratingCommand):
                 stats["count_high_enabled"] += 1
             if record.get("priority") == "critical":
                 stats["count_critical_enabled"] += 1
+            if record.get("priority") == "pending":
+                stats["count_pending_enabled"] += 1
             if record.get("object_state") == "green":
                 stats["count_green_enabled"] += 1
             if record.get("object_state") == "blue":
@@ -259,6 +261,7 @@ class TrackMeGetCollection(GeneratingCommand):
             "count_medium_enabled": 0,
             "count_high_enabled": 0,
             "count_critical_enabled": 0,
+            "count_pending_enabled": 0,
             "count_blue_enabled": 0,
             "count_orange_enabled": 0,
             "count_green_enabled": 0,
