@@ -86,7 +86,6 @@ from collections_data import (
     persistent_fields_flx,
     persistent_fields_fqm,
     persistent_fields_wlk,
-    persistent_fields_cim,
 )
 
 
@@ -140,8 +139,6 @@ class TrackMePersistentHandler(StreamingCommand):
             component = "flx"
         elif collection_name.startswith("trackme_fqm_"):
             component = "fqm"
-        elif collection_name.startswith("trackme_cim_"):
-            component = "cim"
         elif collection_name.startswith("trackme_wlk_"):
             component = "wlk"
         else:
@@ -193,9 +190,6 @@ class TrackMePersistentHandler(StreamingCommand):
         elif component == "fqm":
             for field in persistent_fields_fqm:
                 persistent_fields.append(field)
-        elif component == "cim":
-            for field in persistent_fields_cim:
-                persistent_fields.append(field)
         elif component == "wlk":
             for field in persistent_fields_wlk:
                 persistent_fields.append(field)
