@@ -520,7 +520,7 @@ class AdaptiveDelay(GeneratingCommand):
 
             ``` ML calculations for this object ```
             | fit DensityFunction lag_event_sec lower_threshold=0.005 upper_threshold=0.005 by object
-            | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\d|\.]*))|((?<UpperBound>[\d|\.]*):Infinity)"
+            | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\\d|\\.]*))|((?<UpperBound>[\\d|\\.]*):Infinity)"
             | foreach LowerBound UpperBound [ eval <<FIELD>> = if(isnum('<<FIELD>>'), '<<FIELD>>', 0) ]
             | fields _time object lag_event_sec LowerBound UpperBound
 
@@ -540,7 +540,7 @@ class AdaptiveDelay(GeneratingCommand):
 
                 ``` ML calculations for this object ```
                 | fit DensityFunction lag_event_sec lower_threshold=0.005 upper_threshold=0.005 by object
-                | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\d|\.]*))|((?<UpperBound>[\d|\.]*):Infinity)"
+                | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\\d|\\.]*))|((?<UpperBound>[\\d|\\.]*):Infinity)"
                 | foreach LowerBound UpperBound [ eval <<FIELD>> = if(isnum('<<FIELD>>'), '<<FIELD>>', 0) ]
                 | fields _time object lag_event_sec LowerBound UpperBound
 
@@ -562,7 +562,7 @@ class AdaptiveDelay(GeneratingCommand):
 
                 ``` ML calculations for this object ```
                 | fit DensityFunction lag_event_sec lower_threshold=0.005 upper_threshold=0.005 by object
-                | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\d|\.]*))|((?<UpperBound>[\d|\.]*):Infinity)"
+                | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\\d|\\.]*))|((?<UpperBound>[\\d|\\.]*):Infinity)"
                 | foreach LowerBound UpperBound [ eval <<FIELD>> = if(isnum('<<FIELD>>'), '<<FIELD>>', 0) ]
                 | fields _time object lag_event_sec LowerBound UpperBound
 
@@ -604,7 +604,7 @@ class AdaptiveDelay(GeneratingCommand):
 
             ``` ML calculations for this object ```
             | fit DensityFunction lag_event_sec lower_threshold=0.005 upper_threshold=0.005 by object
-            | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\d|\.]*))|((?<UpperBound>[\d|\.]*):Infinity)"
+            | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\\d|\\.]*))|((?<UpperBound>[\\d|\\.]*):Infinity)"
             | foreach LowerBound UpperBound [ eval <<FIELD>> = if(isnum('<<FIELD>>'), '<<FIELD>>', 0) ]
             | fields _time object lag_event_sec LowerBound UpperBound
 
